var should = require('should');
var es = require('event-stream');
var spawn = require('child_process').spawn;
var path = require('path');
var fs = require('fs');

describe('cli', function() {
  it('should encode a stream with the --format option', function(done) {
    var bin = path.join(__dirname, '..', 'bin', 'json-stream-format');
    var args = [
      '--format', '{{name|capitalize}}',
    ];
    var child = spawn(bin, args);
    fs.createReadStream(path.join(__dirname, 'fixtures', 'example2.log'))
      .pipe(child.stdin);
    child.stdout
      .pipe(es.split())
      .pipe(es.writeArray(function(error, data) {
        data = data.map(function(item) { return item.toString('utf8')});
        data[0].should.equal('First');
        data[12].should.equal('Last');
        data.length.should.equal(15);
        done();
      }));
  });
  it('should encode a stream with the format passed as the arguments', function(done) {
    var bin = path.join(__dirname, '..', 'bin', 'json-stream-format');
    var args = [
      '{{name|capitalize}}',
    ];
    var child = spawn(bin, args);
    fs.createReadStream(path.join(__dirname, 'fixtures', 'example2.log'))
      .pipe(child.stdin);
    child.stdout
      .pipe(es.split())
      .pipe(es.writeArray(function(error, data) {
        data = data.map(function(item) { return item.toString('utf8')});
        data[0].should.equal('First');
        data[12].should.equal('Last');
        data.length.should.equal(15);
        done();
      }));
  });
  it('should encode a stream with the format passed as multiple arguments', function(done) {
    var bin = path.join(__dirname, '..', 'bin', 'json-stream-format');
    var args = [
      '{{',
      'name|capitalize',
      '}}',
      '{{',
      'hostname',
      '}}',
    ];
    var child = spawn(bin, args);
    fs.createReadStream(path.join(__dirname, 'fixtures', 'example2.log'))
      .pipe(child.stdin);
    child.stdout
      .pipe(es.split())
      .pipe(es.writeArray(function(error, data) {
        data = data.map(function(item) { return item.toString('utf8')});
        data[0].should.equal('First example.com');
        data[12].should.equal('Last example.com');
        data.length.should.equal(15);
        done();
      }));
  });
});
